class Zone(object):

    """Manage Zones.

    Args:
        domain: Domain Name 
    """

    def __init__(self, domain, client):
        self.domain = domain
        self.client = client

    def retrieve(self, options={}):
        """Returns a single zone.

        '/zones/:domain/' GET
        """
        body = options['query'] if 'query' in options else {}

        response = self.client.get('/zones/' + self.domain + '/', body, options)

        return response

    def upload(self, data, options={}):
        """Updates a single zone.

        '/zone-upload/:domain/' POST

        Args:
            data: Domain Data
        """
        body = options['body'] if 'body' in options else {}
        body['data'] = data

        response = self.client.post('/zone-upload/' + self.domain + '/', body, options)

        return response

    def destroy(self, options={}):
        """Destroys a single zone.

        '/zones/:domain/' DELETE
        """
        body = options['body'] if 'body' in options else {}

        response = self.client.delete('/zones/' + self.domain + '/', body, options)

        return response

